#!/usr/bin/env python3
# -*- coding: utf-8 -*-
#
"""Python client library for the InterGas InComfort system (via Lan2RF gateway)."""

from __future__ import annotations

import pytest
from common import HOSTNAME, SERIAL_NO_0, SERIAL_NO_1, gwy_with_heaterlist

from incomfortclient import (
    HEATERLIST,
    NULL_SERIAL_NO,
    InvalidGateway,
    InvalidHeaterList,
)

# Test data...
GATEWAYS_SANS_HEATERS = (
    {HEATERLIST: [None, None, None, None, None, None, None, None]},
    {HEATERLIST: [NULL_SERIAL_NO, None, None, None, None, None, None, None]},
    {HEATERLIST: [NULL_SERIAL_NO, NULL_SERIAL_NO, None, None, None, None, None, None]},
)

GATEWAYS_WITH_HEATERS = (
    {HEATERLIST: [SERIAL_NO_0, None, None, None, None, None, None, None]},
    {HEATERLIST: [SERIAL_NO_0, SERIAL_NO_1, None, None, None, None, None, None]},
    {HEATERLIST: [None, NULL_SERIAL_NO, None, None, SERIAL_NO_0, None, None, None]},
)


@pytest.mark.asyncio
async def test_gateway_invalid():
    try:
        await gwy_with_heaterlist(None)
    except InvalidGateway:
        return
    raise AssertionError


@pytest.mark.asyncio
@pytest.mark.parametrize("index", range(len(GATEWAYS_SANS_HEATERS)))
async def test_heaterlist_empty(index, gateways=GATEWAYS_SANS_HEATERS):
    try:
        await gwy_with_heaterlist(HOSTNAME, heaterlist=gateways[index])
    except InvalidHeaterList:
        return
    raise AssertionError


@pytest.mark.asyncio
@pytest.mark.parametrize("index", range(len(GATEWAYS_WITH_HEATERS)))
async def test_heaterlist_valid(index, gateways=GATEWAYS_WITH_HEATERS):
    gwy = await gwy_with_heaterlist(HOSTNAME, heaterlist=gateways[index])

    assert gwy._heaters[0].serial_no == SERIAL_NO_0
    assert len(gwy._heaters) < 2 or gwy._heaters[1].serial_no == SERIAL_NO_1



#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
"""The setup.py file."""

import os
import sys

from setuptools import find_packages, setup
from setuptools.command.install import install

with open("incomfortclient/__init__.py") as fh:
    for line in fh:
        if line.strip().startswith("__version__"):
            VERSION = eval(line.split("=")[-1])
            break

URL = "https://github.com/jbouwh/incomfort-client"

with open("README.md", "r") as fh:
    LONG_DESCRIPTION = fh.read()


class VerifyVersionCommand(install):
    """Custom command to verify that the git tag matches our VERSION."""

    def run(self):
        tag = os.getenv("CIRCLE_TAG")
        if tag != VERSION:
            info = f"Error: git tag ({tag}) does not match the pkg version ({VERSION})"
            sys.exit(info)


setup(
    name="incomfort-client",
    description="An aiohttp-based client for Intergas InComfort/InTouch Lan2RF systems",
    keywords=["intergas", "incomfort", "intouch", "lan2rf"],
    author="Jan Bouwhuis",
    author_email="jan@jbsoft.nl",
    url=URL,
    download_url=f"{URL}/archive/{VERSION}.tar.gz",
    install_requires=[list(val.strip() for val in open("requirements.txt"))],
    long_description=LONG_DESCRIPTION,
    long_description_content_type="text/markdown",
    packages=find_packages(exclude=["test", "docs"]),
    version=VERSION,
    license="MIT",
    python_requires=">=3.9",
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        "Programming Language :: Python :: 3.9",
        "Topic :: Home Automation",
    ],
    cmdclass={
        "verify": VerifyVersionCommand,
    },
)
